@@ -47,6 +47,7 @@ class Client:
         self.session = session or requests.Session()
         self.auth = auth
         self.production_mode = production_mode
+        self.assume_merchant = ""
 
         self.base_url = self._set_base_url(**options)
         print("baseURL, " + self.base_url)
@@ -65,6 +66,10 @@ class Client:
             del (options['base_url'])
         return base_url
 
+    def set_assume_merchant(self, merchant):
+        if(merchant):
+            self.assume_merchant = merchant
+
     def encode_jwt(self, secret=str, scope="direct_debit",
                    redirect_url=None,
                    reference_id=str(uuid.uuid4())[:8],
@@ -131,6 +136,7 @@ class Client:
         response = getattr(self.session, method)(url, headers={
             'Authorization': auth_header,
             'Content-Type': 'application/json;charset=UTF-8',
+            'X-ASSUME-MERCHANT': self.assume_merchant
         }, **options)
         if ((response.status_code >= HTTP_STATUS_CODE.OK) and
                 (response.status_code < HTTP_STATUS_CODE.REDIRECT)):
@@ -146,7 +152,7 @@ class Client:
                     msg = json_response['resultInfo']['message']
                 if 'code' in json_response['resultInfo']:
                     code = str(json_response['resultInfo']['code'])
-            elif str.upper(code) == ERROR_CODE.SERVER_ERROR:
+            if str.upper(code) == ERROR_CODE.SERVER_ERROR:
                 raise ServerError(msg)
             else:
                 raise ServerError(msg)
@@ -216,7 +222,7 @@ class Client:
         if data is not None:
             _data = json.dumps(data)
             content_type = "application/json;charset=UTF-8"
-        uri_path = "/v2" + path
+        uri_path = path
         _auth_header = self.auth_header(
                        self.auth[0],
                        self.auth[1],
